@@ -1,28 +1,49 @@
 package the;
 use 5.006001;
 no warnings 'redefine';
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 sub import {
     my $package = caller;
     *{"${package}::$_"} = sub { return wantarray ? @_ : $_[0] }
-        for qw(a an teh the);
+        for qw(a an teh the more);
     my ($class, $module) = @_;
     if ($module) {
         eval "require $module";
         die $@ if $@;
         splice @_, 0, 1;
-        goto &{ $module->can('import') };
+        my $import = $module->can('import')
+            or return;
+        goto &$import;
     }
 }
 
+sub unimport {
+    my $package = caller;
+    *{"${package}::$_"} = sub { return wantarray ? @_ : $_[0] }
+        for qw(a an teh the more);
+    my ($class, $module) = @_;
+    if ($module) {
+        eval "require $module";
+        die $@ if $@;
+        splice @_, 0, 1;
+        my $unimport = $module->can('unimport')
+            or return;
+        goto &$unimport;
+    }
+}
+
+
 *{"a::"} =
 *{"an::"} =
+*{"more::"} =
 *{"teh::"} =
 *{"the::"};
 
 1;
 
+=encoding utf8
+
 =head1 NAME
 
 the - This is teh, best module evar!
@@ -35,10 +56,12 @@ the - This is teh, best module evar!
 
     the my an $a = teh $b + a $c;
 
+    no more 'Moose';
+
 =head1 DESCRIPTION
 
 teh module exports the subroutine and the module exports a subroutine.
-Just use an module, then use a subroutine.
+Just use an module, then use more subroutine.
 
 =head1 AUTHOR
 
